@@ -95,6 +95,9 @@ namespace MagickLib
 #  define MagickDLLDeclExtern
 #endif
 
+#if defined(WIN32) && defined(_VISUALC_)
+#  pragma warning(disable : 4996) /* function deprecation warnings */
+#endif
 
 //
 // Import ImageMagick symbols and types which are used as part of the
@@ -130,6 +133,7 @@ namespace Magick
   using MagickLib::BlackChannel;
   using MagickLib::MatteChannel;
   using MagickLib::DefaultChannels;
+  using MagickLib::AllChannels;
   
   // Color-space types
   using MagickLib::CMYKColorspace;
@@ -298,6 +302,10 @@ namespace Magick
   using MagickLib::PlaneInterlace;
   using MagickLib::PartitionInterlace;
 
+  // Layer method
+  using MagickLib::FlattenLayer;
+  using MagickLib::MosaicLayer;
+
   // Line cap types
   using MagickLib::LineCap;
   using MagickLib::UndefinedCap;
@@ -400,6 +408,9 @@ namespace Magick
   using MagickLib::AbsoluteIntent;
   using MagickLib::RelativeIntent;
   
+  // Resource types
+  using MagickLib::MemoryResource;
+
   // Resolution units
   using MagickLib::ResolutionType;
   using MagickLib::UndefinedResolution;
@@ -451,11 +462,12 @@ namespace Magick
   //
   // ImageMagick symbols used in implementation code
   //
-  using MagickLib::AcquireCacheView;
+  using MagickLib::AcquireCacheViewPixels;
   using MagickLib::AcquireImagePixels;
   using MagickLib::AcquireMagickMemory;
   using MagickLib::AcquireString;
 	using MagickLib::AcquireStringInfo;
+  using MagickLib::AdaptiveBlurImage;
   using MagickLib::AdaptiveThresholdImage;
   using MagickLib::AddNoiseImage;
   using MagickLib::AffineMatrix;
@@ -465,6 +477,7 @@ namespace Magick
   using MagickLib::AspectValue;
   using MagickLib::Base64Decode;
   using MagickLib::Base64Encode;
+  using MagickLib::BilevelImage;
   using MagickLib::BlobError;
   using MagickLib::BlobFatalError;
   using MagickLib::BlobToImage;
@@ -474,9 +487,9 @@ namespace Magick
   using MagickLib::CacheError;
   using MagickLib::CacheFatalError;
   using MagickLib::CacheWarning;
-  using MagickLib::ChannelImage;
   using MagickLib::CharcoalImage;
   using MagickLib::ChopImage;
+  using MagickLib::ClearMagickException;
   using MagickLib::CloneDrawInfo;
   using MagickLib::CloneImage;
   using MagickLib::CloneImageInfo;
@@ -485,7 +498,6 @@ namespace Magick
   using MagickLib::CoderError;
   using MagickLib::CoderFatalError;
   using MagickLib::CoderWarning;
-  using MagickLib::ColorFloodfillImage;
   using MagickLib::ColorizeImage;
   using MagickLib::ColorPacket;
   using MagickLib::CompositeImage;
@@ -504,19 +516,18 @@ namespace Magick
   using MagickLib::DelegateError;
   using MagickLib::DelegateFatalError;
   using MagickLib::DelegateWarning;
-  using MagickLib::DeleteMagickRegistry;
+  using MagickLib::DeleteImageOption;
+  using MagickLib::DeleteImageRegistry;
   using MagickLib::DespeckleImage;
   using MagickLib::DestroyDrawInfo;
   using MagickLib::DestroyDrawingWand;
   using MagickLib::DestroyExceptionInfo;
   using MagickLib::DestroyImageInfo;
   using MagickLib::DestroyImageList;
-  using MagickLib::DestroyMagick;
   using MagickLib::DestroyMagickWand;
   using MagickLib::DestroyPixelWand;
   using MagickLib::DestroyQuantizeInfo;
   using MagickLib::DestroyStringInfo;
-  using MagickLib::DispatchImage;
   using MagickLib::DisplayImages;
   using MagickLib::DrawAffine;
   using MagickLib::DrawAllocateWand;
@@ -561,11 +572,11 @@ namespace Magick
   using MagickLib::DrawPolyline;
   using MagickLib::DrawPopClipPath;
   using MagickLib::DrawPopDefs;
-  using MagickLib::DrawPopGraphicContext;
+  using MagickLib::PopDrawingWand;
   using MagickLib::DrawPopPattern;
   using MagickLib::DrawPushClipPath;
   using MagickLib::DrawPushDefs;
-  using MagickLib::DrawPushGraphicContext;
+  using MagickLib::PushDrawingWand;
   using MagickLib::DrawPushPattern;
   using MagickLib::DrawRectangle;
   using MagickLib::DrawRender;
@@ -575,7 +586,7 @@ namespace Magick
   using MagickLib::DrawSetClipPath;
   using MagickLib::DrawSetClipRule;
   using MagickLib::DrawSetClipUnits;
-  using MagickLib::DrawSetFillAlpha;
+  using MagickLib::DrawSetFillOpacity;
   using MagickLib::DrawSetFillColor;
   using MagickLib::DrawSetFillPatternURL;
   using MagickLib::DrawSetFillRule;
@@ -586,7 +597,7 @@ namespace Magick
   using MagickLib::DrawSetFontStyle;
   using MagickLib::DrawSetFontWeight;
   using MagickLib::DrawSetGravity;
-  using MagickLib::DrawSetStrokeAlpha;
+  using MagickLib::DrawSetStrokeOpacity;
   using MagickLib::DrawSetStrokeAntialias;
   using MagickLib::DrawSetStrokeColor;
   using MagickLib::DrawSetStrokeDashArray;
@@ -613,24 +624,25 @@ namespace Magick
   using MagickLib::EvaluateImageChannel;
   using MagickLib::ExceptionInfo;
   using MagickLib::ExceptionType;
-  using MagickLib::ExecuteModuleProcess;
+  using MagickLib::ExportImagePixels;
   using MagickLib::ExportQuantumPixels;
   using MagickLib::FileOpenError;
   using MagickLib::FileOpenFatalError;
   using MagickLib::FileOpenWarning;
-  using MagickLib::FlattenImages;
   using MagickLib::FlipImage;
   using MagickLib::FlopImage;
-  using MagickLib::FormatString;
+  using MagickLib::FormatMagickString;
   using MagickLib::FrameImage;
   using MagickLib::FrameInfo;
   using MagickLib::GammaImage;
   using MagickLib::GammaImage;
   using MagickLib::GaussianBlurImage;
-  using MagickLib::GetCacheView;
+  using MagickLib::GetAffineMatrix;
+  using MagickLib::GetBlobSize;
+  using MagickLib::GetCacheViewPixels;
   using MagickLib::GetCacheViewIndexes;
-  using MagickLib::GetImageChannelExtrema;
   using MagickLib::GetImageChannelMean;
+  using MagickLib::GetImageChannelRange;
   using MagickLib::GetImageClipMask;
   using MagickLib::GetColorTuple;
   using MagickLib::GetDrawInfo;
@@ -647,46 +659,46 @@ namespace Magick
   using MagickLib::GetImageQuantizeError;
   using MagickLib::GetImageType;
   using MagickLib::GetIndexes;
-  using MagickLib::GetMagickGeometry;
   using MagickLib::GetMagickInfo;
-  using MagickLib::GetMagickRegistry;
+  using MagickLib::GetMagickPixelPacket;
   using MagickLib::GetNumberColors;
   using MagickLib::GetPageGeometry;
   using MagickLib::GetPixels;
   using MagickLib::GetQuantizeInfo;
   using MagickLib::GetQuantumInfo;
+  using MagickLib::GetStringInfoDatum;
+  using MagickLib::GetStringInfoLength;
   using MagickLib::GetTypeMetrics;
   using MagickLib::GlobExpression;
   using MagickLib::GreaterValue;
-  using MagickLib::HSLTransform;
+  using MagickLib::ConvertHSLToRGB;
   using MagickLib::HeightValue;
-  using MagickLib::IdentityAffine;
   using MagickLib::ImageError;
   using MagickLib::ImageFatalError;
   using MagickLib::ImageInfo;
-  using MagickLib::ImageInfoRegistryType;
   using MagickLib::ImageRegistryType;
   using MagickLib::ImageToBlob;
   using MagickLib::ImageWarning;
   using MagickLib::ImplodeImage;
   using MagickLib::ImportQuantumPixels;
+  using MagickLib::InvokeDynamicImageFilter;
   using MagickLib::IsEventLogging;
   using MagickLib::IsGeometry;
   using MagickLib::IsImagesEqual;
-  using MagickLib::IsSubimage;
   using MagickLib::LessValue;
   using MagickLib::LevelImage;
   using MagickLib::LevelImageChannel;
   using MagickLib::LocaleCompare;
   using MagickLib::LogMagickEvent;
+  using MagickLib::MagickCoreTerminus;
   using MagickLib::MagickInfo;
   using MagickLib::MagickPixelPacket;
   using MagickLib::MagickToMime;
   using MagickLib::MagickWand;
   using MagickLib::MagnifyImage;
   using MagickLib::MapImage;
-  using MagickLib::MatteFloodfillImage;
   using MagickLib::MedianFilterImage;
+  using MagickLib::MergeImageLayers;
   using MagickLib::MinifyImage;
   using MagickLib::MissingDelegateError;
   using MagickLib::MissingDelegateFatalError;
@@ -706,12 +718,15 @@ namespace Magick
   using MagickLib::NoiseType;
   using MagickLib::NormalizeImage;
   using MagickLib::OilPaintImage;
-  using MagickLib::OpaqueImage;
   using MagickLib::OpenCacheView;
   using MagickLib::OptionError;
   using MagickLib::OptionFatalError;
   using MagickLib::OptionWarning;
+  using MagickLib::PaintFloodfillImage;
+  using MagickLib::ParseMetaGeometry;
   using MagickLib::PercentValue;
+  using MagickLib::PaintOpaqueImage;
+  using MagickLib::PaintTransparentImage;
   using MagickLib::PingBlob;
   using MagickLib::PingImage;
   using MagickLib::PixelSetQuantumColor;
@@ -723,6 +738,7 @@ namespace Magick
   using MagickLib::QuantizeInfo;
   using MagickLib::QuantumInfo;
   using MagickLib::QueryColorDatabase;
+  using MagickLib::QueryMagickColor;
   using MagickLib::RGBTransformImage;
   using MagickLib::RaiseImage;
   using MagickLib::ReadImage;
@@ -735,7 +751,6 @@ namespace Magick
   using MagickLib::RegistryType;
   using MagickLib::RegistryWarning;
   using MagickLib::RelinquishMagickMemory;
-  using MagickLib::RemoveImageOption;
   using MagickLib::ResizeImage;
   using MagickLib::ResizeMagickMemory;
   using MagickLib::ResourceLimitError;
@@ -746,13 +761,14 @@ namespace Magick
   using MagickLib::SampleImage;
   using MagickLib::ScaleImage;
   using MagickLib::SegmentImage;
-  using MagickLib::SetCacheThreshold;
+  using MagickLib::SeparateImageChannel;
   using MagickLib::SetCacheView;
   using MagickLib::SetClientName;
-  using MagickLib::SetImage;
+  using MagickLib::SetImageBackgroundColor;
   using MagickLib::SetImageChannelDepth;
   using MagickLib::SetImageClipMask;
   using MagickLib::SetImageDepth;
+  using MagickLib::SetImageExtent;
   using MagickLib::SetImageInfo;
   using MagickLib::SetImageOpacity;
   using MagickLib::SetImageOption;
@@ -762,7 +778,8 @@ namespace Magick
   using MagickLib::SetImageType;
   using MagickLib::SetLogEventMask;
   using MagickLib::SetMagickInfo;
-  using MagickLib::SetMagickRegistry;
+  using MagickLib::SetImageRegistry;
+  using MagickLib::SetMagickResourceLimit;
   using MagickLib::SetStringInfoDatum;
   using MagickLib::ShadeImage;
   using MagickLib::SharpenImage;
@@ -770,7 +787,6 @@ namespace Magick
   using MagickLib::ShearImage;
   using MagickLib::SigmoidalContrastImageChannel;
   using MagickLib::SignatureImage;
-  using MagickLib::SizeBlob;
   using MagickLib::SolarizeImage;
   using MagickLib::SpreadImage;
   using MagickLib::SteganoImage;
@@ -784,12 +800,10 @@ namespace Magick
   using MagickLib::SyncImage;
   using MagickLib::SyncImagePixels;
   using MagickLib::TextureImage;
-  using MagickLib::ThresholdImage;
   using MagickLib::ThrowException;
-  using MagickLib::TransformHSL;
+  using MagickLib::ConvertRGBToHSL;
   using MagickLib::TransformImage;
   using MagickLib::TransformRGBImage;
-  using MagickLib::TransparentImage;
   using MagickLib::TrimImage;
   using MagickLib::TypeError;
   using MagickLib::TypeFatalError;
