@@ -1,5 +1,5 @@
 /*
-  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization
+  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization
   dedicated to making software imaging solutions freely available.
   
   You may not use this file except in compliance with the License.
@@ -70,6 +70,7 @@ typedef struct _DelegateInfo
     mode;
                                                                                 
   MagickBooleanType
+    thread_support,
     spawn,
     stealth;
                                                                                 
@@ -97,7 +98,7 @@ extern MagickExport long
   GetDelegateMode(const DelegateInfo *);
 
 extern MagickExport MagickBooleanType
-  InvokePostscriptDelegate(const MagickBooleanType,const char *),
+  GetDelegateThreadSupport(const DelegateInfo *),
   InvokeDelegate(ImageInfo *,Image *,const char *,const char *,ExceptionInfo *),
   ListDelegateInfo(FILE *,ExceptionInfo *);
 
