@@ -1,5 +1,5 @@
 /*
-  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization
+  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization
   dedicated to making software imaging solutions freely available.
   
   You may not use this file except in compliance with the License.
@@ -30,11 +30,52 @@ typedef enum
   MultiplicativeGaussianNoise,
   ImpulseNoise,
   LaplacianNoise,
-  PoissonNoise
+  PoissonNoise,
+  RandomNoise
 } NoiseType;
 
+typedef enum
+{
+  UndefinedPreview,
+  RotatePreview,
+  ShearPreview,
+  RollPreview,
+  HuePreview,
+  SaturationPreview,
+  BrightnessPreview,
+  GammaPreview,
+  SpiffPreview,
+  DullPreview,
+  GrayscalePreview,
+  QuantizePreview,
+  DespecklePreview,
+  ReduceNoisePreview,
+  AddNoisePreview,
+  SharpenPreview,
+  BlurPreview,
+  ThresholdPreview,
+  EdgeDetectPreview,
+  SpreadPreview,
+  SolarizePreview,
+  ShadePreview,
+  RaisePreview,
+  SegmentPreview,
+  SwirlPreview,
+  ImplodePreview,
+  WavePreview,
+  OilPaintPreview,
+  CharcoalDrawingPreview,
+  JPEGPreview
+} PreviewType;
+
 extern MagickExport Image
-  *AdaptiveThresholdImage(const Image *,const unsigned long,const unsigned long,    const long,ExceptionInfo *),
+  *AdaptiveBlurImage(const Image *,const double,const double,ExceptionInfo *),
+  *AdaptiveBlurImageChannel(const Image *,const ChannelType,const double,
+    const double,ExceptionInfo *),
+  *AdaptiveSharpenImage(const Image *,const double,const double,
+     ExceptionInfo *),
+  *AdaptiveSharpenImageChannel(const Image *,const ChannelType,const double,
+    const double,ExceptionInfo *),
   *AddNoiseImage(const Image *,const NoiseType,ExceptionInfo *),
   *AddNoiseImageChannel(const Image *,const ChannelType,const NoiseType,
     ExceptionInfo *),
@@ -66,15 +107,6 @@ extern MagickExport Image
   *UnsharpMaskImageChannel(const Image *,const ChannelType,const double,
     const double,const double,const double,ExceptionInfo *);
 
-extern MagickExport MagickBooleanType
-  BlackThresholdImage(Image *,const char *),
-  BilevelImage(Image *,const double),
-  BilevelImageChannel(Image *,const ChannelType,const double),
-  RandomThresholdImage(Image *,const char *,ExceptionInfo *),
-  RandomThresholdImageChannel(Image *,const ChannelType,const char *,
-    ExceptionInfo *),
-  WhiteThresholdImage(Image *,const char *);
-
 #if defined(__cplusplus) || defined(c_plusplus)
 }
 #endif
