@@ -1,5 +1,5 @@
 /*
-  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization
+  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization
   dedicated to making software imaging solutions freely available.
   
   You may not use this file except in compliance with the License.
@@ -66,12 +66,12 @@ extern MagickExport unsigned long
 
 extern MagickExport void
   ClearLinkedList(LinkedListInfo *,void *(*)(void *)),
-  *GetLastValueInLinkedList(const LinkedListInfo *),
+  *GetLastValueInLinkedList(LinkedListInfo *),
   *GetNextKeyInHashmap(HashmapInfo *),
   *GetNextValueInHashmap(HashmapInfo *),
   *GetNextValueInLinkedList(LinkedListInfo *),
-  *GetValueFromHashmap(const HashmapInfo *,const void *),
-  *GetValueFromLinkedList(const LinkedListInfo *,const unsigned long),
+  *GetValueFromHashmap(HashmapInfo *,const void *),
+  *GetValueFromLinkedList(LinkedListInfo *,const unsigned long),
   *RemoveElementByValueFromLinkedList(LinkedListInfo *,const void *),
   *RemoveElementFromLinkedList(LinkedListInfo *,const unsigned long),
   *RemoveEntryFromHashmap(HashmapInfo *,const void *),
