@@ -22,6 +22,10 @@
 extern "C" {
 #endif
 
+typedef MagickBooleanType
+  (*MagickProgressMonitor)(const char *,const MagickOffsetType,
+    const MagickSizeType,void *);
+
 MagickExport MagickProgressMonitor
   SetImageProgressMonitor(Image *,const MagickProgressMonitor,void *),
   SetImageInfoProgressMonitor(ImageInfo *,const MagickProgressMonitor,void *);
