@@ -1,5 +1,5 @@
 /*
-  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization
+  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization
   dedicated to making software imaging solutions freely available.
   
   You may not use this file except in compliance with the License.
@@ -26,11 +26,11 @@ extern "C" {
 #include "magick/draw.h"
 
 extern MagickExport MagickBooleanType
-  ColorFloodfillImage(Image *,const DrawInfo *,const PixelPacket,const long,
-    const long,const PaintMethod),
-  MatteFloodfillImage(Image *,const PixelPacket,const Quantum,const long,
-    const long,const PaintMethod),
+  PaintFloodfillImage(Image *,const ChannelType,const MagickPixelPacket *,
+    const long,const long,const DrawInfo *,const PaintMethod),
   PaintOpaqueImage(Image *,const MagickPixelPacket *,const MagickPixelPacket *),
+  PaintOpaqueImageChannel(Image *,const ChannelType,const MagickPixelPacket *,
+    const MagickPixelPacket *),
   PaintTransparentImage(Image *,const MagickPixelPacket *,const Quantum);
 
 #if defined(__cplusplus) || defined(c_plusplus)
