@@ -1,5 +1,5 @@
 /*
-  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization
+  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization
   dedicated to making software imaging solutions freely available.
   
   You may not use this file except in compliance with the License.
@@ -24,6 +24,30 @@ extern "C" {
 
 #include "magick/string_.h"
 
+typedef struct _ProfileInfo
+{
+  char
+    *name;
+
+  size_t
+    length;
+
+  unsigned char
+    *info;
+
+  unsigned long
+    signature;
+} ProfileInfo;
+
+typedef enum
+{
+  UndefinedIntent,
+  SaturationIntent,
+  PerceptualIntent,
+  AbsoluteIntent,
+  RelativeIntent
+} RenderingIntent;
+
 extern MagickExport char
   *GetNextImageProfile(const Image *);
 
@@ -32,10 +56,14 @@ extern MagickExport const StringInfo
 
 extern MagickExport MagickBooleanType
   CloneImageProfiles(Image *,const Image *),
-  ProfileImage(Image *,const char *,const void *,const unsigned long,
+  DeleteImageProfile(Image *,const char *),
+  ProfileImage(Image *,const char *,const void *,const size_t,
     const MagickBooleanType),
-  RemoveImageProfile(Image *,const char *),
-  SetImageProfile(Image *,const char *,const StringInfo *);
+  SetImageProfile(Image *,const char *,const StringInfo *),
+  SyncImageProfiles(Image *);
+
+extern MagickExport StringInfo
+  *RemoveImageProfile(Image *,const char *);
 
 extern MagickExport void
   DestroyImageProfiles(Image *),
